using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using MySql.Data;
using MySql.Data.MySqlClient;

public partial class Category : System.Web.UI.Page
{
    protected void Page_Load(object sender, System.EventArgs e)
    {
        // Check to assertain that the page load not is a post back.
        if (!Page.IsPostBack)
        {

            // Request the PageName parameter value in the url.
            if (Request.QueryString["PageName"] != null)
                HiddenPageName.Value = Request.QueryString["PageName"];

            // When the page loads we select data from the categoryTbl table according to the PageName parameter the we
            // get from the url by interpret the url in the web.config file.

            // Declare a connection string and a SELECT statement.
            string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sql = "SELECT * FROM categoryTbl WHERE PageName = @PageName";
            
            // Create a MySqlConnection. The using block is used to call dispose (close) automatically even 
            // if there are an exception.
            using (MySqlConnection cn = new MySqlConnection(ConnString))
            {
                // Create a MySqlCommand.
                MySqlCommand cmd = new MySqlCommand(sql, cn);

                // Create a MySqlDataReader.
                MySqlDataReader reader = null;

                // Add parameters.
                cmd.Parameters.AddWithValue("@PageName", HiddenPageName.Value);

                // The Try/Catch/Finally block is used to handle exceptions.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // The using block is used to call dispose (close) automatically even if there are an exception.
                    reader = cmd.ExecuteReader(CommandBehavior.SingleRow);

                    // Loop the reader.
                    while (reader.Read())
                    {
                        HiddenCategoryID.Value = reader["Id"].ToString();
                        HeadLiteral.Text = reader["Name"].ToString();
                        ltTitle.Text = reader["MetaTitle"].ToString();
                        ltDescription.Text = "<meta name=\"description\" content=\"" + reader["MetaDescription"].ToString() + "\"/>";
                        ltKeywords.Text = "<meta name=\"keywords\" content=\"" + reader["MetaKeywords"].ToString() + "\"/>";
                        ltRobots.Text = "<meta name=\"robots\" content=\"noindex, follow\"/>";
                        ltCanonical.Text = "<link rel=\"canonical\" href=\"" + "http://www.mypage.com/category/" + HiddenPageName.Value + ".aspx" + "\"/>";
                    }
                }
                catch (Exception ex)
                {
                    Response.Write(ex.Message);
                }
                finally
                {
                    // Dispose MySqlCommand
                    cmd.Dispose();

                    // Close the MySqlDataReader if it not is null.
                    if (reader != null)
                        reader.Close();
                }

                // This word below calls the subroutin "BindData" that is used to fill the repeater control with content.
                BindData();
            }
        }
    }

    protected void BindData()
    {
        // We select data from the contentTbl according to the selected CategoryID in the page load event.
        // The selected data is used to bind data to a repeater.

        // Declare a connection string and a SELECT statement.
        string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "SELECT * FROM contentTbl WHERE CategoryID = @CategoryID ORDER BY Name ASC";

        // Create a MySqlConnection. The using block is used to call dispose (close) automatically even if there 
        // are an exception.
        using (MySqlConnection cn = new MySqlConnection(ConnString))
        {
            // Create a MySqlDataAdapter.
            MySqlDataAdapter sad = new MySqlDataAdapter();

            // Create a MySqlCommand.
            MySqlCommand cmd = new MySqlCommand(sql, cn);

            // Create a DataTable
            DataTable dt = new DataTable();

            // Create a PagedDataSource.
            PagedDataSource objPds = new PagedDataSource();

            // Add parameters.
            cmd.Parameters.AddWithValue("@CategoryId", HiddenCategoryID.Value);

            // The Try/Catch/Finally block is used to handle exceptions.
            try
            {
                // Open the connection.
                cn.Open();

                // Set the SelectCommand for the adapter.
                sad.SelectCommand = cmd;

                // Add data to the DataTable from the adapter.
                sad.Fill(dt);

                // Populate the repeater control with the datatable 
                objPds.DataSource = dt.DefaultView;

                // Indicate that the data should be paged 
                objPds.AllowPaging = true;

                // Set the pagesize 
                objPds.PageSize = 10;

                // Print out pageinformation with navigationlinks
                Int32 curpage = 1;

                // Set the value for the current page.
                if (Request.QueryString["Page"] != null)
                {
                    curpage = Convert.ToInt32(Request.QueryString["Page"]);
                }
                else
                {
                    curpage = 1;
                }

                // Set the CurrentPageIndex.
                objPds.CurrentPageIndex = curpage - 1;

                // Set text for the lblCurrentPage label.
                lblCurrentPage.Text = "| Page: " + curpage.ToString() + " av " + objPds.PageCount.ToString() + " |";

                if (!objPds.IsFirstPage)
                {
                    lnkPrev.Visible = true;
                    lnkPrev.NavigateUrl = GeneratePageURL(HiddenPageName.Value) + "page-" + Convert.ToString(curpage - 1) + ".aspx";
                }

                if (!objPds.IsLastPage)
                {
                    lnkNext.Visible = true;
                    lnkNext.NavigateUrl = GeneratePageURL(HiddenPageName.Value) + "page-" + Convert.ToString(curpage + 1) + ".aspx";
                }

                // Bind data to the Repeater control.
                ContentListRepeater.DataSource = objPds;
                ContentListRepeater.DataBind();

            }
            catch (Exception ex)
            {
                Response.Write(ex.Message);
            }
            finally
            {
                // Dispose to avoid memory leakage.
                sad.Dispose();
                cmd.Dispose();
                dt.Dispose();
            }
        }
    }

    protected string GenerateURL(object Contentname)
    {

        //Create SEO Friendly URL for each content link
        string strConUrl = "~/article/" + Contentname + ".aspx";

        return strConUrl;
    }

    protected string GeneratePageURL(object Catname)
    {

        // Create SEO Friendly URL for each category page
        string strCatUrl = "~/category/" + Catname + "/";

        return strCatUrl;
    }
}
